pub enum CryptoMaterialError {
SerializationError,
DeserializationError,
ValidationError,
WrongLengthError,
CanonicalRepresentationError,
SmallSubgroupError,
PointNotOnCurveError,
BitVecError(String),
}Expand description
An error type for key and signature validation issues, see ValidCryptoMaterial.
This enum reflects there are two interesting causes of validation failure for the ingestion of key or signature material: deserialization errors (often, due to mangled material or curve equation failure for ECC) and validation errors (material recognizable but unacceptable for use, e.g. unsafe).
Variants
SerializationError
Struct to be signed does not serialize correctly.
DeserializationError
Key or signature material does not deserialize correctly.
ValidationError
Key or signature material deserializes, but is otherwise not valid.
WrongLengthError
Key, threshold or signature material does not have the expected size.
CanonicalRepresentationError
Part of the signature or key is not canonical resulting to malleability issues.
SmallSubgroupError
A curve point (i.e., a public key) lies on a small group.
PointNotOnCurveError
A curve point (i.e., a public key) does not satisfy the curve equation.
BitVecError(String)
BitVec errors in accountable multi-sig schemes.