Validatable

Struct Validatable 

pub struct Validatable<V: Validate> { /* private fields */ }
Used in connection with the Validate trait to be able to represent types which can benefit from deferred validation as a performance optimization.

Implementations

Source

impl<V: Validate> Validatable<V>

pub fn new_valid(valid: V) -> Self

Create a new Validatable from a valid type

pub fn new_unvalidated(unvalidated: V::Unvalidated) -> Self

Create a new Validatable from an unvalidated type

pub fn unvalidated(&self) -> &V::Unvalidated

Return a reference to the unvalidated form V::Unvalidated

pub fn valid(&self) -> Option<&V>

Try to validate the unvalidated form returning Some(&V) on success and None on failure.

pub fn validate(&self) -> Result<&V>

Attempt to validate V::Unvalidated and return a reference to a valid V